package com.altinity.opsview.odw.elements;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.text.DecimalFormat;
import java.util.List;

import org.dom4j.Element;

import com.altinity.opsview.odw.ReportConstants;
import com.altinity.opsview.odw.bc.ODWReportBC;
import com.altinity.opsview.odw.bc.ODWReportLogger;
import com.altinity.opsview.odw.dao.ODWReportConfigDAO;
import com.altinity.opsview.odw.dao.ODWReportDAO;
import com.altinity.opsview.odw.exception.ReportException;
import com.altinity.opsview.odw.model.AvailabilityModel;
import com.altinity.opsview.odw.reports.ReportCriteria;

public class HostGroupAvailability extends AbstractReportElement implements ReportConstants {
	
	private List <AvailabilityModel> l;

	/**
	 * 
	 */
	public HostGroupAvailability(ReportCriteria rc, ODWReportDAO dao, ODWReportConfigDAO configDao, ODWReportLogger log) {
		super(rc, dao, configDao, log);
	}

	/**
	 * 
	 */
	@Override
	public Element addElement(Element elements) {

		Element hostGroupAvailability= elements.addElement("element");
		hostGroupAvailability.addAttribute("name", "hostgroup-summary");
		hostGroupAvailability.addElement("title").setText("Hostgroup Availability Summary");		
		
		// Set empty boolean if there is no data
		if ( l.isEmpty() ) {
			
			hostGroupAvailability.addElement("empty").setText("true");
			
			// Report error 
			log.getErrors().add("No data found for module 'Hostgroup Availability Summary'");
			
			return hostGroupAvailability;
		}
		
		// Data has been returned, build host group elements
		DecimalFormat percentFormat = new DecimalFormat(PERCENT_FORMAT);
		Element hostGroups = hostGroupAvailability.addElement("hostgroups");
		
		for ( AvailabilityModel availabilityModel : l ){
			
			Element hostgroup = hostGroups.addElement("hostgroup");
			hostgroup.addElement("name").setText(availabilityModel.getHostGroupName());
			
			double warning = availabilityModel.getHostGroup().getWarning();
			hostgroup.addElement("warn").setText(Double.toString(warning));
			
			double critical = availabilityModel.getHostGroup().getCritical();
			hostgroup.addElement("crit").setText(Double.toString(critical));
			
			double availability = availabilityModel.getAverageAvailablility();
			hostgroup.addElement("availability").setText(percentFormat.format(availability));
			hostgroup.addElement("scheduled-downtime").setText(percentFormat.format(availabilityModel.getScheduledDowntime()));
			hostgroup.addElement("unscheduled-downtime").setText(percentFormat.format(availabilityModel.getUnscheduledDowntime()));
			
			// Colour text according to average availability
			if ( availability <= warning && availability > critical )
				hostgroup.addAttribute("color", "#" + ODWReportBC.HEX_WARNING);
			else if ( availability <= critical )
				hostgroup.addAttribute("color", "red");
			else
				hostgroup.addAttribute("color", "black");	
		}
		
		return hostGroupAvailability;
	}
	
	/**
	 * 
	 */
	public void runQuery() throws ReportException {
		
		l = dao.getAvailabilityForHostGroups(configDao, rc);
	}

}
