package com.excira.utils;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.regex.Pattern;

public class DateUtils {
	
	private static long MILLIS_PER_DAY = 24l * 60l * 60l * 1000l;
	private static long MILLIS_PER_HOUR = 60l * 60l * 1000l;
	private static long MILLIS_PER_MINUTE = 60l * 1000l;
	private static long MILLIS_PER_SECOND = 1000l;
	
	/**
	 * Returns string representing date with default
	 * pattern of yyyy-MM-dd
	 */
	public static String format(Date date) {
		return format(date, "yyyy-MM-dd");
	}
	
	/**
	 * Create string representing date with specified pattern 
	 */
	public static String format(Date date, String pattern) {
		
		SimpleDateFormat formatter = new SimpleDateFormat(pattern);
		return formatter.format(date);
	}
	
	/**
	 * 
	 */
	public static Date parse(String strDate) {
		
		return parse(strDate, "yyyy-MM-dd");
	}
	
	/**
	 * Creates Date object from specified string
	 */
	public static Date parse(String strDate, String pattern) {
		
		Date date = null;
		try {
			
			date = new SimpleDateFormat(pattern).parse(strDate);
		}
		catch(Exception e) {
			System.out.println("Error in DateUtils.format");
			System.out.println("Invalid date string specifed: " + strDate);
			e.printStackTrace();
		}
		return date;
	}
		
	/**
	 * Returns true if date can be parsed to specified pattern
	 */
	public static boolean isValidDate(String strDate, String regEx, String pattern) {
		
		// Allow empty string dates
		if ( strDate.equals("") )
			return true;
		
		// First check date against regular expression
		// Return false if it does not match
		if ( StringUtils.notNullOrEmpty(regEx) && 
				!Pattern.matches(regEx, strDate) )
			return false;
		
		// Now check date is valid
		return ( parse(strDate, pattern) != null );
	}
	
	/**
	 * Returns the current date
	 */
	public static Date getNow() {
		return Calendar.getInstance().getTime();
	}
	
	/**
	 * 
	 */
	public static String getDurationString(long duration) {
		
		long days = 0l;
		long hours = 0l;
		long minutes = 0l;
		long seconds = 0l;
		
		// First calculate how many days in duration
		if ( duration >= MILLIS_PER_DAY ) {
			
			days = duration / MILLIS_PER_DAY;
			duration = duration % MILLIS_PER_DAY;
		}
			
		// Calculate how many hours in duration
		if ( duration >= MILLIS_PER_HOUR ) {
			
			hours = duration / MILLIS_PER_HOUR;
			duration = duration % MILLIS_PER_HOUR;
		}
		
		// Calculate how many minute in duration
		if ( duration >= MILLIS_PER_MINUTE ) {
			
			minutes = duration / MILLIS_PER_MINUTE;
			duration = duration % MILLIS_PER_MINUTE;
		}
		
		// Calculate how many second in duration
		if ( duration >= MILLIS_PER_SECOND ) {
			
			seconds = duration / MILLIS_PER_SECOND;
			duration = duration % MILLIS_PER_SECOND;
		}
		
		StringBuffer sb = new StringBuffer();
		sb.append(days);
		sb.append("d ");
		sb.append(hours);
		sb.append("h ");
		sb.append(minutes);
		sb.append("m ");
		sb.append(seconds);
		sb.append("s ");
		return sb.toString();
	}
	
	/**
	 * 
	 */
	public static void clearHourMinuteSecond(Calendar cal) {
		
		cal.set(Calendar.HOUR_OF_DAY, 0);//dave was here
		cal.set(Calendar.MINUTE, 0);
		cal.set(Calendar.SECOND, 0);
		cal.set(Calendar.MILLISECOND, 0);
	}
	
	/**
	 * 
	 */
	public static void setMaxHourMinuteSecond(Calendar cal) {
		
		cal.set(Calendar.HOUR_OF_DAY, 23);
		cal.set(Calendar.MINUTE, 59);
		cal.set(Calendar.SECOND, 59);
	}	
	
	/**
	 * 
	 */
	public static boolean isDateEqual(Date d1, Date d2) {
		
		Calendar c1 = Calendar.getInstance();
		c1.setTime(d1);
		
		Calendar c2 = Calendar.getInstance();
		c2.setTime(d2);
		
		return
			(c1.get(Calendar.YEAR) == c2.get(Calendar.YEAR)) &&
			(c1.get(Calendar.MONTH) == c2.get(Calendar.MONTH)) &&
			(c1.get(Calendar.DATE) == c2.get(Calendar.DATE));
	}
	
	/**
	 * 
	 */
	public static boolean isBefore(Date date, Date compareTo) {
		
		SimpleDateFormat format = new SimpleDateFormat("yyyyMMdd");
		
		int intDate = new Integer(format.format(date));
		int intCompareTo = new Integer(format.format(compareTo));
		
		return intDate < intCompareTo;
	}
	
	/**
	 * 
	 */
	public static void adjustDateAccordingToWeekConfigToGetFirstDayOfWeek(Calendar cal, int dayOfWeek) {
		
		cal.setMinimalDaysInFirstWeek(4);	// for calculating week in year this will match mysql 
		cal.setFirstDayOfWeek(dayOfWeek);  // week can start any day of week
		cal.set(Calendar.DAY_OF_WEEK, dayOfWeek); // change the day of the calendar 
	}
	
	/**
	 * 
	 */
	public static int getLastDayOfWeek(int firstDayOfWeek) {
		
		return (6 + firstDayOfWeek) % 7;
	}
	
	/**
	 * 
	 */
	public static int getDayOfWeek(int day) {
		
		int dow = day % 7;
		if ( dow == 0 )
			return 7;
		
		return dow;
	}
	
	/**
	 * 
	 */
	public static Calendar getConfiguredCalendar(int minFirstWeek, int startOfWeek, Date date) {
		
		Calendar cal = Calendar.getInstance();
		cal.setTime(date);
		cal.setMinimalDaysInFirstWeek(minFirstWeek);
		cal.setFirstDayOfWeek(startOfWeek);
		
		return cal;
	}
}

