<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE foo [
	<!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:attribute-set name="bold">
		<xsl:attribute name="font-weight">bold</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name="center">
		<xsl:attribute name="text-align">center</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="element">
		<xsl:attribute name="margin-top">30px</xsl:attribute>
	</xsl:attribute-set>	
	
	<xsl:attribute-set name="elementHeading">
		<xsl:attribute name="font-size">12px</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="margin-bottom">15px</xsl:attribute>
	</xsl:attribute-set>		
	
	<xsl:attribute-set name="elementSubHeading">
		<xsl:attribute name="font-size">8px</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="margin-bottom">5px</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="right">
		<xsl:attribute name="text-align">right</xsl:attribute>
	</xsl:attribute-set>	

	<xsl:attribute-set name="table">
		<xsl:attribute name="font-size">8px</xsl:attribute>
		<xsl:attribute name="border">1px solid #999999</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="tableCell">
		<xsl:attribute name="border">1px solid #cccccc</xsl:attribute>
		<xsl:attribute name="padding">2px</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="tableCellBreakdown">
		<xsl:attribute name="padding">0 0 0 11px</xsl:attribute>
		<xsl:attribute name="width">490px</xsl:attribute>
	</xsl:attribute-set>	
	
	<xsl:attribute-set name="tableCellIndex">
		<xsl:attribute name="border">1px solid #cccccc</xsl:attribute>
		<xsl:attribute name="padding">2px</xsl:attribute>
		<xsl:attribute name="width">20px</xsl:attribute>
	</xsl:attribute-set>		
	
	<xsl:attribute-set name="text">
		<xsl:attribute name="font-size">8px</xsl:attribute>
	</xsl:attribute-set>	
	
	<xsl:include href="../elements/WeeklyServiceSummary.xsl"/>
	<xsl:include href="../elements/WeeklyServiceSummaryTable.xsl"/>
	<xsl:include href="../elements/WeeklyServiceManagementSummary.xsl"/>
	<xsl:include href="../elements/WeeklyServiceDetail.xsl"/>
	<xsl:include href="../elements/ErrorsSummary.xsl"/>

	<!-- *************************************************************************************************
	Root
	*************************************************************************************************** -->
	<xsl:template match="report">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
		 	<xsl:call-template name="layout-master-set"/>
		 	<xsl:call-template name="cover-page"/>
		 	<xsl:apply-templates select="/report/report-sections/section"/>
		</fo:root>
	</xsl:template>
	
	<!-- *************************************************************************************************
	 Cover Page
	*************************************************************************************************** -->
	<xsl:template name="cover-page">
		<fo:page-sequence force-page-count="no-force">
			<xsl:attribute name="master-reference">
				<xsl:value-of select="/report/@report-cover-format" />
			</xsl:attribute> 		
			<fo:flow flow-name="xsl-region-body" >
				<fo:block space-after="2cm"> <fo:external-graphic src="url('{assets-root}{logo}')" content-width="10cm"/></fo:block>
				<fo:block font-weight="bold"><xsl:value-of select="title"/></fo:block>
				<fo:block space-after="5cm" font-weight="bold"><xsl:value-of select="report-type"/></fo:block>
				<fo:block font-weight="bold">Reporting Period: </fo:block>
				<fo:block space-after="2.5mm" ><xsl:value-of select="start-date"/> to <xsl:value-of select="end-date"/></fo:block>
				<fo:block font-weight="bold">Report Generated On: </fo:block>
				<fo:block><xsl:value-of select="run-date"/></fo:block>
			</fo:flow>		
		</fo:page-sequence>
	</xsl:template>
	
	<!-- *************************************************************************************************
	Section
	*************************************************************************************************** -->
	<xsl:template name="section" match="section">
		<fo:page-sequence >
			<xsl:attribute name="master-reference">
				<xsl:choose>
					<xsl:when test="@section-format">
						<xsl:value-of select="@section-format" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="/report/@report-format" />
					</xsl:otherwise>
				</xsl:choose>			
			</xsl:attribute> 		
			<!-- Header -->
			<fo:static-content flow-name="xsl-region-before">
				<fo:block text-align="left" font-weight="bold" border-after-style="solid" border-after-width="medium"><xsl:value-of select="title"/></fo:block>
			</fo:static-content> 
			<!-- Footer -->
			<xsl:call-template name="report-footer"/>
			<fo:flow flow-name="xsl-region-body">
				<fo:block></fo:block>
				<xsl:apply-templates select="elements/element"/>
				<xsl:if test="@lastSection='true'"><fo:block id="theEnd"/></xsl:if>
			</fo:flow> 
		</fo:page-sequence> 
	</xsl:template>
	
	<!-- *************************************************************************************************
		Element Title
	*************************************************************************************************** -->
	<xsl:template name="element-title">
		<fo:block border-before-style="solid" border-before-width="thick" space-after="0.5cm">
				<fo:table table-layout="fixed"  text-align="left">
					<fo:table-column column-width="100%"/>
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell >
								<fo:block  background-color="#dddddd"><xsl:value-of select="title"/></fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</fo:block>
	</xsl:template>
	
	<!-- *************************************************************************************************
	Report Footer
	*************************************************************************************************** -->
	<xsl:template name="report-footer">
		<fo:static-content flow-name="xsl-region-after">
			<fo:block border-after-style="solid" border-after-width="thin">
				<fo:table table-layout="fixed" xsl:use-attribute-sets="center">
					<fo:table-column column-width="33.3%"/>
					<fo:table-column column-width="33.3%"/>
					<fo:table-column column-width="33.3%"/>
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<fo:block text-align="left" font-weight="bold">Opsview Reports</fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block text-align="center">Page <fo:page-number/> of <fo:page-number-citation ref-id="theEnd"/></fo:block>
							</fo:table-cell>
							<fo:table-cell>
								<fo:block  text-align="right"><xsl:value-of select="/report/start-date"/> to <xsl:value-of select="/report/end-date"/></fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</fo:block>
		</fo:static-content> 	
	</xsl:template>	
	
	
	<!-- *************************************************************************************************
	Layout Master Set
	*************************************************************************************************** -->
	<xsl:template name="layout-master-set">
		<fo:layout-master-set>
		  <fo:simple-page-master master-name="coverA4"
		                  page-height="29.7cm"
		                  page-width="21cm"
		                  margin-top="1cm"
		                  margin-bottom="1cm"
		                  margin-left="2.5cm"
		                  margin-right="2.5cm">
		      <fo:region-body margin-top="3cm"/>
		      <fo:region-before extent="1cm"/>
		      <fo:region-after extent="1cm"/>
		  </fo:simple-page-master>
	
		  <fo:simple-page-master master-name="reportA4"
		                  page-height="21cm"
		                  page-width="29.7cm"
		                  margin-top="1cm"
		                  margin-bottom="1cm"
		                  margin-left="1.5cm"
		                  margin-right="1.5cm">
		      <fo:region-body margin-top="1cm" margin-bottom="1cm"/>
		      <fo:region-before extent="1cm"/>
		      <fo:region-after extent="1cm"/>
		  </fo:simple-page-master>
		  
		  <fo:simple-page-master master-name="reportA4Portrait"
		                  page-height="29.7cm"
		                  page-width="21cm"
		                  margin-top="1cm"
		                  margin-bottom="1cm"
		                  margin-left="1.5cm"
		                  margin-right="1.5cm">
		      <fo:region-body margin-top="1cm" margin-bottom="1cm"/>
		      <fo:region-before extent="1cm"/>
		      <fo:region-after extent="1cm"/>
		  </fo:simple-page-master>		  
		  
		  <fo:simple-page-master master-name="coverUS"
		                  page-height="11in"
		                  page-width="8.5in"
		                  margin-top="0.5in"
		                  margin-bottom="0.5in"
		                  margin-left="0.5in"
		                  margin-right="0.5in">
		      <fo:region-body margin-top="1.5in"/>
		      <fo:region-before extent="0.5in"/>
		      <fo:region-after extent="0.5in"/>
		  </fo:simple-page-master>		  
		  
		  <fo:simple-page-master master-name="reportUS"
		                  page-height="8.5in"
		                  page-width="11in"
		                  margin-top="0.5in"
		                  margin-bottom="0.5in"
		                  margin-left="0.5in"
		                  margin-right="0.5in">
		      <fo:region-body margin-top="0.5in" margin-bottom="0.5in"/>
		      <fo:region-before extent="0.5in"/>
		      <fo:region-after extent="0.5in"/>
		  </fo:simple-page-master>
		  
		  <fo:simple-page-master master-name="reportUSPortrait"
		                  page-height="11in"
		                  page-width="8.5in"
		                  margin-top="0.5in"
		                  margin-bottom="0.5in"
		                  margin-left="0.5in"
		                  margin-right="0.5in">
		      <fo:region-body margin-top="0.5in" margin-bottom="0.5in"/>
		      <fo:region-before extent="0.5in"/>
		      <fo:region-after extent="0.5in"/>
		  </fo:simple-page-master>		  
		  
		</fo:layout-master-set>
	</xsl:template>
	
</xsl:stylesheet>